@@ -48,7 +48,10 @@ plotmo.pairs.gbm <- function(object, ...)
     # pairs of four most important variables (i.e. 6 plots)
     importance <- attr(object, "plotmo.importance")
     stopifnot(!is.null(importance)) # uninitialized?
-    form.pairs(importance[1: min(4, length(importance))])
+    # choose npairs so a total of no more than 16 plots
+    # npairs=5 gives 10 pairplots, npairs=4 gives 6 pairplots
+    npairs <- if(length(importance) <= 6) 5 else 4
+    form.pairs(importance[1: min(npairs, length(importance))])
 }
 # following is used by plotmo.x.gbm and plotmo.x.GBMFit
 plotmo.x.gbm.aux <- function(x, x.order, var.levels)
